#!/bin/csh -f
#
# Usage link_exe.jc param_file_# potential_name
#
# C shell script used to link the object files to an executable on
# linux
#
set polydir = `cat ~/.poly_path9.3`
set potdir = $polydir/obj
set libdir = $polydir/obj
set wrkdir = $polydir/obj
set exedir = $polydir/exe
set srcdir = $polydir/src
#
cd $wrkdir
#
if ($#argv != 2) then
   echo "Usage: link_exe.jc param_file_# potential_name"
   echo "For example: link_exe.jc 2 ch5"
   exit 1
endif
#
#  check the library file
#
if (! -e $libdir/libpoly$argv[1].a) then
   echo "Library file $libdir/libpoly$argv[1].a doesn't exist."
   echo "Please run comp_src.jc to compile the source code first."
   exit 2
endif
#
#  check the potential object file
#
if (! -e $potdir/$argv[2].o) then
   echo "Potential object $potdir/$argv[2].o doesn't exist."
   echo "Please run potcomp.jc to compile the potential file first."
   exit 3
endif
#
#  link the object files together into an executable file
#
echo "$libdir"
echo "libpoly$argv[1].a"
echo "$argv[2].o"
echo "poly_$argv[2].exe"
#
#   cp $srcdir/main.o $libdir/main$argv[1].o
#   cd $wrkdir
#
#  link the object files together into an executable file
#
g77 libpoly$argv[1].a $argv[2].o -o poly_$argv[2].exe
#
#cc -o poly_$argv[2].exe -lf2c -lm -L $libdir libpoly$argv[1].a \
#      $argv[2].o 
#
mv poly_$argv[2].exe $exedir
echo "The executable poly_$argv[2].exe has been created and put in "
echo "$exedir."
#
#  echo information to .doc file in exe directory
#
set file = $exedir/poly_$argv[2].doc
echo "The executable was created `date`." > $file
echo "The potential file used was $potdir/$argv[2].o." >> $file
echo "The parameter file used was param$argv[1].inc." >> $file
#
#End of script link_exe.linux
